package com.palmnest.dao.estateserve;

import java.util.List;
import java.util.Map;

import org.springframework.ui.ModelMap;

import com.palmnest.application.bean.Pagenation;
import com.palmnest.dao.GenericDao;

/**
 * 商城数据层接口
 *
 * @version 1.0
 * @authr xiemin
 */
public interface ShoppingMallDao extends GenericDao<Object, Integer> {

	/**
	 * 查询场地资源列表
	 *
	 * @param map
	 * @return
	 * @throws Exception
	 */
	public Pagenation<Map<String, String>> queryMallList(ModelMap modelMap) throws Exception;

	/**
	 * 添加商城信息
	 *
	 * @param modelMap
	 * @return
	 */
	public int addMallUrl(ModelMap modelMap) throws Exception;

	/**
	 * 根据名称查询项目列表
	 *
	 * @param mallName
	 * @return
	 */
	public List<Map<String, String>> findByNameList(String mallName);

	/**
	 * 查询详情
	 *
	 * @param id
	 * @return
	 */
	public Map<String, String> queryDetails(String id);

	/**
	 * 禁用启用
	 *
	 * @param id
	 * @param status
	 * @return
	 * @throws Exception
	 */
	int mallDelete(String id, String status) throws Exception;

	/**
	 * 根据key查询url
	 *
	 * @param urlKey
	 * @return
	 */
	public Map<String, String> queryUrlKey(String urlKey);

	/**
	 * 查询adcode
	 *
	 * @param organizationId
	 * @return
	 */
	public String queryAddressCode(String organizationId);

}
	
    
